@@ -8,15 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@pahud/cdk-github-oidc",
-    "0.0.12",
+    "0.0.46",
     __name__[0:-6],
-    "cdk-github-oidc@0.0.12.jsii.tgz",
+    "cdk-github-oidc@0.0.46.jsii.tgz",
 )
 
 __all__ = [
